schema

package
v0.0.0-...-116c032 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 3, 2025 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Merchant

type Merchant struct {
	ent.Schema
}

Merchant holds the schema definition for the Merchant entity.

func (Merchant) Edges

func (Merchant) Edges() []ent.Edge

Edges of the Merchant.

func (Merchant) Fields

func (Merchant) Fields() []ent.Field

Fields of the Merchant.

func (Merchant) Mixin

func (Merchant) Mixin() []ent.Mixin

type MerchantAccount

type MerchantAccount struct {
	ent.Schema
}

MerchantAccount holds the schema definition for the MerchantAccount entity.

func (MerchantAccount) Edges

func (MerchantAccount) Edges() []ent.Edge

Edges of the MerchantAccount.

func (MerchantAccount) Fields

func (MerchantAccount) Fields() []ent.Field

Fields of the MerchantAccount.

func (MerchantAccount) Indexes

func (MerchantAccount) Indexes() []ent.Index

func (MerchantAccount) Mixin

func (MerchantAccount) Mixin() []ent.Mixin

type PlatformAccount

type PlatformAccount struct {
	ent.Schema
}

PlatformAccount holds the schema definition for the PlatformAccount entity.

func (PlatformAccount) Edges

func (PlatformAccount) Edges() []ent.Edge

Edges of the PlatformAccount.

func (PlatformAccount) Fields

func (PlatformAccount) Fields() []ent.Field

Fields of the PlatformAccount.

func (PlatformAccount) Mixin

func (PlatformAccount) Mixin() []ent.Mixin

type TimeMixin

type TimeMixin struct {
	// We embed the `mixin.Schema` to avoid
	// implementing the rest of the methods.
	mixin.Schema
}

TimeMixin implements the ent.Mixin for sharing time fields with package schemas.

func (TimeMixin) Fields

func (TimeMixin) Fields() []ent.Field

func (TimeMixin) Indexes

func (TimeMixin) Indexes() []ent.Index

type User

type User struct {
	ent.Schema
}

User holds the schema definition for the User entity.

func (User) Edges

func (User) Edges() []ent.Edge

Edges of the User.

func (User) Fields

func (User) Fields() []ent.Field

Fields of the User.

func (User) Mixin

func (User) Mixin() []ent.Mixin

type UserLoginMethod

type UserLoginMethod struct {
	ent.Schema
}

UserLoginMethod holds the schema definition for the UserLoginMethod entity.

func (UserLoginMethod) Edges

func (UserLoginMethod) Edges() []ent.Edge

Edges of the UserLoginMethod.

func (UserLoginMethod) Fields

func (UserLoginMethod) Fields() []ent.Field

Fields of the UserLoginMethod.

func (UserLoginMethod) Mixin

func (UserLoginMethod) Mixin() []ent.Mixin

Jump to